/*
 * This file is part of WebLookAndFeel library.
 *
 * WebLookAndFeel library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * WebLookAndFeel library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WebLookAndFeel library.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.alee.demo;

import com.alee.demo.style.WebLafDemoSkin;
import com.alee.laf.WebLookAndFeel;
import com.alee.laf.rootpane.WebFrame;
import com.alee.managers.language.LanguageManager;
import com.alee.managers.settings.SettingsManager;
import com.alee.managers.style.StyleManager;

/**
 * WebLaF demo application.
 * This class contains demo application base UI.
 *
 * @author Mikle Garin
 */

public class WebLafDemo extends WebFrame
{
    /**
     * Constructs new WebLaF demo application frame.
     */
    public WebLafDemo ()
    {
        super ();
    }

    /**
     * Launches WebLaF demo application.
     * All provided arguments are ignored so far.
     *
     * @param args arguments
     */
    public static void main ( final String[] args )
    {
        // Exampler settings location
        SettingsManager.setDefaultSettingsDirName ( ".weblaf-demo" );
        SettingsManager.setDefaultSettingsGroup ( "WebLafDemo" );
        SettingsManager.setSaveOnChange ( true );

        // Default demo language for now
        LanguageManager.setDefaultLanguage ( LanguageManager.ENGLISH );

        // Demo application skin
        // It extends default WebLaF skin and adds some custom styling
        StyleManager.setDefaultSkin ( WebLafDemoSkin.class.getCanonicalName () );

        // Look and Feel
        WebLookAndFeel.install ();
    }
}